<?php

/**
 * @file
 * Contains Drupal\snippet_manager\Entity\Snippet.
 */

namespace Drupal\snippet_manager\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\snippet_manager\SnippetInterface;

/**
 * Defines the snippet entity type.
 *
 * @ConfigEntityType(
 *   id = "snippet",
 *   label = @Translation("Snippet"),
 *   handlers = {
 *     "view_builder" = "Drupal\snippet_manager\SnippetViewBuilder",
 *     "list_builder" = "Drupal\snippet_manager\Controller\SnippetListBuilder",
 *     "form" = {
 *       "add" = "Drupal\snippet_manager\Form\SnippetForm",
 *       "edit" = "Drupal\snippet_manager\Form\SnippetForm",
 *       "delete" = "Drupal\snippet_manager\Form\SnippetDeleteForm",
 *       "variable_add" = "Drupal\snippet_manager\Form\VariableAddForm",
 *       "variable_edit" = "Drupal\snippet_manager\Form\VariableEditForm",
 *       "variable_delete" = "Drupal\snippet_manager\Form\VariableDeleteForm"
 *     }
 *   },
 *   config_prefix = "snippet",
 *   admin_permission = "administer snippet",
 *   links = {
 *     "collection" = "/admin/structure/snippet",
 *     "canonical" = "/admin/structure/snippet/{snippet}",
 *     "add-form" = "/admin/structure/snippet/add",
 *     "edit-form" = "/admin/structure/snippet/{snippet}",
 *     "delete-form" = "/admin/structure/snippet/{snippet}/delete"
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   }
 * )
 */
class Snippet extends ConfigEntityBase implements SnippetInterface {

  /**
   * The snippet ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The snippet label.
   *
   * @var string
   */
  protected $label;

  /**
   * The snippet description.
   *
   * @var string
   */
  protected $description;

  /**
   * The snippet code.
   *
   * @var array
   */
  protected $code;

  /**
   * The snippet variables.
   *
   * @var array
   */
  protected $variables = [];


  /**
   * {@inheritdoc}
   */
  public function getCode() {
    return $this->code ? $this->code : [
        'value' => "\n\n\n",
        'format' => filter_default_format(),
      ];
  }

  /**
   * {@inheritdoc}
   */
  public function setCode(array $code) {
    return $this->code = $code;
  }

  /**
   * {@inheritdoc}
   */
  public function getVariables() {
    return $this->variables;
  }

  /**
   * {@inheritdoc}
   */
  public function setVariables($variables) {
    $this->variables = $variables;
  }

  /**
   * {@inheritdoc}
   */
  public function getVariable($key) {
    return $this->variables[$key];
  }

  /**
   * {@inheritdoc}
   */
  public function setVariable($key, $variable) {
    $this->variables[$key] = $variable;
  }

  /**
   * {@inheritdoc}
   */
  public function removeVariable($key) {
    unset($this->variables[$key]);
  }

  /**
   * {@inheritdoc}
   */
  public function variableExists($key) {
    return isset($this->variables[$key]);
  }

}
