<?php

/**
 * @file
 * Contains \Drupal\snippet_manager\Plugin\Block\SnippetBlock.
 */

namespace Drupal\snippet_manager\Plugin\Block;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Block\BlockBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\snippet_manager\Entity\Snippet;
use Drupal\snippet_manager\SnippetRenderer;
use Drupal\Core\Entity\EntityViewBuilderInterface;
use Drupal\Core\Logger\LoggerChannelInterface;

/**
 * Provides a 'Snippet' block.
 *
 * @Block(
 *   id = "snippet",
 *   admin_label = @Translation("Snippet"),
 *   category = @Translation("Snippet"),
 *   deriver = "Drupal\snippet_manager\Plugin\Block\SnippetBlockDeriver"
 * )
 */
class SnippetBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Snippet renderer.
   *
   * @var \Drupal\snippet_manager\SnippetRenderer
   */
  protected $snippetRenderer;

  /**
   * Entity view builder.
   *
   * @var \Drupal\Core\Entity\EntityViewBuilderInterface
   */
  protected $viewBuilder;

  /**
   * Snippet renderer.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Constructs a new SnippetBlock instance.
   *
   * @param array $configuration
   *   The plugin configuration, i.e. an array with configuration values keyed
   *   by configuration option name. The special key 'context' may be used to
   *   initialize the defined contexts by setting it to an array of context
   *   values keyed by context names.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\snippet_manager\SnippetRenderer $snippet_renderer
   *   Snippet renderer service.
   * @param \Drupal\Core\Entity\EntityViewBuilderInterface $view_builder
   *   The entity view builder.
   * @param \Drupal\Core\Logger\LoggerChannelInterface $logger
   *   The logger channel.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, SnippetRenderer $snippet_renderer, EntityViewBuilderInterface $view_builder, LoggerChannelInterface $logger) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->snippetRenderer = $snippet_renderer;
    $this->viewBuilder = $view_builder;
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('snippet_manager.renderer'),
      $container->get('entity.manager')->getViewBuilder('snippet'),
      $container->get('logger.channel.snippet_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];

    /** @var \Drupal\snippet_manager\SnippetInterface $snippet */
    $snippet = Snippet::load($this->getDerivativeId());
    if ($snippet) {
      $build = $this->viewBuilder->view($snippet);
    }
    else {
      $this->logger->error('Could not load snippet: #%snippet', ['%snippet' => $this->configuration['snippet']]);
    }

    return $build;
  }

}
