<?php

/**
 * @file
 * Contains \Drupal\snippet_manager\Plugin\SnippetVariable\ConditionDeriver.
 */

namespace Drupal\snippet_manager\Plugin\SnippetVariable;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Condition\ConditionManager;

/**
 * Retrieves snippet variable plugin definitions for all views.
 */
class ConditionDeriver extends DeriverBase implements ContainerDeriverInterface {

  /**
   * The condition manager.
   *
   * @var \Drupal\Core\Condition\ConditionManager
   */
  protected $conditionManager;

  /**
   * Constructs ConditionDeriver object.
   *
   * @param \Drupal\Core\Condition\ConditionManager $condition_manager
   *   The condition manager.
   */
  public function __construct(ConditionManager $condition_manager) {
    $this->conditionManager = $condition_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('plugin.manager.condition')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {

    foreach ($this->conditionManager->getDefinitions() as $condition_id => $definition) {
      $this->derivatives[$condition_id] = $base_plugin_definition;
      $this->derivatives[$condition_id]['title'] = $definition['label'];
    }

    return $this->derivatives;
  }

}
