<?php

/**
 * @file
 * Contains \Drupal\snippet_manager\Plugin\SnippetVariable\Text.
 */

namespace Drupal\snippet_manager\Plugin\SnippetVariable;

use Drupal\Core\Form\FormStateInterface;
use Drupal\snippet_manager\SnippetVariableBase;
use Drupal\snippet_manager\SnippetVariableInterface;

/**
 * Provides text variable type.
 *
 * @SnippetVariable(
 *   id = "text",
 *   title = @Translation("Text"),
 *   category = @Translation("Other"),
 * )
 */
class Text extends SnippetVariableBase implements SnippetVariableInterface {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {

    $form['content'] = array(
      '#title' => t('Content'),
      '#type' => 'text_format',
      '#default_value' => $this->getValue(),
      '#rows' => 10,
      '#format' => $this->getFormat(),
      '#editor' => FALSE,
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['value'] = $values['content']['value'];
    $this->configuration['format'] = $values['content']['format'];
  }

  /**
   * Returns variable value.
   */
  protected function getValue() {
    return isset($this->configuration['value']) ?
      $this->configuration['value'] : filter_default_format();
  }

  /**
   * Returns variable format.
   */
  protected function getFormat() {
    return isset($this->configuration['format']) ?
      $this->configuration['format'] : '';
  }

  /**
   * {@inheritdoc}
   */
  public function getContent() {
    return [
      '#type' => 'processed_text',
      '#text' => $this->getValue(),
      '#format' => $this->getFormat(),
    ];
  }

}
