<?php

/**
 * @file
 * Contains \Drupal\snippet_manager\SnippetRenderer.
 */

namespace Drupal\snippet_manager;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Template\TwigEnvironment;

/**
 * SnippetRenderer description.
 */
class SnippetRenderer implements SnippetRendererInterface {

  /**
   * Twig environment.
   *
   * @var \Drupal\Core\Template\TwigEnvironment
   */
  protected $twig;

  /**
   * The variable manager.
   *
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $variableManager;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs a SnippetRenderer object.
   *
   * @param \Drupal\Core\Template\TwigEnvironment $twig
   *   The Twig environment.
   * @param \Drupal\Component\Plugin\PluginManagerInterface $variable_manager
   *   Variable manager.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   */
  public function __construct(TwigEnvironment $twig, PluginManagerInterface $variable_manager, RendererInterface $renderer) {
    $this->twig = $twig;
    $this->variableManager = $variable_manager;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public function render(SnippetInterface $snippet, array $twig_variables = []) {

    foreach ($snippet->getVariables() as $variable_name => $variable) {
      $plugin = $this->variableManager->createInstance(
        $variable['plugin_id'],
        $variable['configuration']
      );

      $variable_content = $plugin->getContent();
      $twig_variables[$variable_name] = is_array($variable_content) ?
        $this->renderer->renderRoot($variable_content) : $variable_content;
    }

    $code = $snippet->getCode();

    return $this->twig->renderInline(
      check_markup($code['value'], $code['format']),
      $twig_variables
    );
  }

}
