<?php

/**
 * @file
 * Contains \Drupal\snippet_manager\SnippetViewBuilder.
 */

namespace Drupal\snippet_manager;

use Drupal\Component\Utility\Timer;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Render\Element;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides snippet view builder.
 */
class SnippetViewBuilder extends EntityViewBuilder {

  /**
   * Snippet renderer.
   *
   * @var \Drupal\snippet_manager\SnippetRenderer
   */
  protected $snippetRenderer;

  /**
   * Constructs a new SnippetViewBuilder.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity manager service.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   * @param \Drupal\snippet_manager\SnippetRenderer $snippet_renderer
   *   Snippet renderer service.
   */
  public function __construct(EntityTypeInterface $entity_type, EntityTypeManagerInterface $entity_type_manager, LanguageManagerInterface $language_manager, SnippetRenderer $snippet_renderer) {
    parent::__construct($entity_type, $entity_type_manager, $language_manager);
    $this->snippetRenderer = $snippet_renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $entity_type,
      $container->get('entity.manager'),
      $container->get('language_manager'),
      $container->get('snippet_manager.renderer')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function view(EntityInterface $entity, $view_mode = 'full', $langcode = NULL) {

    /** @var \Drupal\snippet_manager\SnippetInterface $entity */
    if ($view_mode == 'admin') {
      $build = $this->viewAdmin($entity);
    }
    else {
      $build['snippet'] = [
        '#type' => 'container',
        '#attributes' => ['class' => ['snippet']],
      ];
      $build['snippet']['content']['#markup'] = $this->snippetRenderer->render($entity);
    }

    return $build;
  }

  /**
   * Builds the render array for the provided snippet using admin view mode.
   */
  public function viewAdmin(EntityInterface $entity) {
    /** @var \Drupal\snippet_manager\SnippetInterface $entity */

    $build['snippet']['content']['#type'] = 'textarea';
    Timer::start('snippet');
    $build['snippet']['content']['#value'] = $this->snippetRenderer->render($entity);
    $render_time = Timer::read('snippet');
    $build['snippet']['content']['#attributes']['class'][] = 'snippet-html-source';

    $build['snippet']['#attributes']['class'][] = 'snippet-admin';

    $build['render_time_wrapper'] = [
      '#type' => 'container',
      '#attributes' => ['class' => 'snippet-render-time'],
    ];
    $build['render_time_wrapper']['render_time'] = [
      '#markup' => t('Render time: %time ms', ['%time' => $render_time]),
    ];

    $build['#attached']['library'][] = 'snippet_manager/snippet_manager';

    return $build;
  }

}
